@@ -17,83 +17,87 @@
 
 #include "FunctionCallTip.h"
 
+#include <cstring>
+#include <locale>
+#include <memory>
+#include <sstream>
+#include <vector>
+
+#include <Scintilla.h>
+
+#include "NppXml.h"
 
 struct Token {
-	wchar_t * token;
+	Token() = delete;
+	explicit Token(char* tok, int len, bool isID) noexcept : token(tok), length(len), isIdentifier(isID) {}
+
+	char* token;
 	int length;
 	bool isIdentifier;
-	Token(wchar_t* tok, int len, bool isID) : token(tok), length(len), isIdentifier(isID) {}
 };
 
 struct FunctionValues {
-	int lastIdentifier;
-	int lastFunctionIdentifier;
-	int param;
-	int scopeLevel;
-	FunctionValues() : lastIdentifier(-1), lastFunctionIdentifier(-1), param(0), scopeLevel(-1) {}
+	int lastIdentifier = -1;
+	int lastFunctionIdentifier = -1;
+	int param = 0;
+	int scopeLevel = -1;
 };
 
-inline bool lower(wchar_t c) {
-	return (c >= 'a' && c <= 'z');	
-}
-
-inline bool match(wchar_t c1, wchar_t c2) {
-	if (c1 == c2)	return true;
-	if (lower(c1))
-		return ((c1-32) == c2);
-	if (lower(c2))
-		return ((c2-32) == c1);
-	return false;	
-}
-
 //test string case insensitive ala Scintilla
 //0 if equal, <0 of before, >0 if after (name1 that is)
-int testNameNoCase(const wchar_t * name1, const wchar_t * name2, int len = -1)
+static int testNameNoCase(const char* name1, const char* name2, int len = -1)
 {
+	static const auto loc = std::locale("");
 	if (len == -1)
 	{
-		len = 1024;	//magic value, but it probably fails way before it reaches this
+		len = 1024; //magic value, but it probably fails way before it reaches this
 	}
-	int i = 0;
-	while (match(name1[i], name2[i]))
+
+	for (int i = 0; i < len; ++i)
 	{
-		if (name1[i] == 0 || i == len)
+		const unsigned char char1 = name1[i];
+		const unsigned char char2 = name2[i];
+
+		if (char1 == '\0' || char2 == '\0') // null terminator check
+			return char1 - char2;
+
+		if (char1 == char2) // equal
+			continue;
+
+		// compare ignoring case
+		if (std::tolower(char1, loc) != std::tolower(char2, loc))
 		{
-			return 0;	//equal	
+			return char1 - char2;
 		}
-		++i;	
 	}
-	
-	int subs1 = lower(name1[i])?32:0;
-	int subs2 = lower(name2[i])?32:0;
-	
-	return ( (name1[i]-subs1) - (name2[i]-subs2) );
+
+	return 0; // equal up to specified length.
 }
 
-void FunctionCallTip::setLanguageXML(TiXmlElement * pXmlKeyword)
+void FunctionCallTip::setLanguageXML(NppXml::Element xmlKeyword)
 {
 	if (isVisible())
 		close();
-	_pXmlKeyword = pXmlKeyword;
+	_xmlKeyword = xmlKeyword;
 
 	// Clear all buffered values, because they may point to freed memory area.
 	reset();
 
 	// Also clear _funcName so that next getCursorFunction will call loadFunction to parse XML structure
-	delete [] _funcName;
-	_funcName = 0;
+	_funcName.reset(nullptr);
 }
 
 bool FunctionCallTip::updateCalltip(int ch, bool needShown)
 {
-	if (!needShown && ch != _start && ch != _param && !isVisible())		//must be already visible
+	if (!needShown && ch != _start && ch != _param && !isVisible()) //must be already visible
 		return false;
 
 	_curPos = _pEditView->execute(SCI_GETCURRENTPOS);
 
 	//recalculate everything
 	if (!getCursorFunction())
-	{	//cannot display calltip (anymore)
+	{
+		//cannot display calltip (anymore)
 		close();
 		return false;
 	}
@@ -116,7 +120,7 @@ void FunctionCallTip::showPrevOverload()
 {
 	if (!isVisible())
 		return;
-	_currentOverload = _currentOverload > 0 ? (_currentOverload-1) : (_currentNbOverloads-1);
+	_currentOverload = _currentOverload > 0 ? (_currentOverload - 1) : (_currentNbOverloads - 1);
 	showCalltip();
 }
 
@@ -137,7 +141,7 @@ bool FunctionCallTip::getCursorFunction()
 	intptr_t endpos = _pEditView->execute(SCI_GETLINEENDPOSITION, line);
 	intptr_t len = endpos - startpos + 3;	//also take CRLF in account, even if not there
 	intptr_t offset = _curPos - startpos;	//offset is cursor location, only stuff before cursor has influence
-	const intptr_t maxLen = 256;
+	static constexpr intptr_t maxLen = 256;
 
 	if ((offset < 2) || (len >= maxLen))
 	{
@@ -145,43 +149,41 @@ bool FunctionCallTip::getCursorFunction()
 		return false;	//cannot be a func, need name and separator
 	}
 	
-	wchar_t lineData[maxLen] = L"";
+	char lineData[maxLen]{};
 
 	_pEditView->getLine(line, lineData, len);
 
 	//line aquired, find the functionname
 	//first split line into tokens to parse
 	//token is identifier or some expression, whitespace is ignored
-	std::vector< Token > tokenVector;
-	int tokenLen = 0;
+	std::vector<Token> tokenVector;
 
-	for (int i = 0; i < offset; ++i) 	//we don't care about stuff after the offset
-    {
+	for (int i = 0; i < offset; ++i) //we don't care about stuff after the offset
+	{
 		//tokenVector.push_back(pair(lineData+i, len));
-		wchar_t ch = lineData[i];
-		if (isBasicWordChar(ch) || isAdditionalWordChar(ch))	//part of identifier
-        {
-			tokenLen = 0;
-			wchar_t * begin = lineData+i;
-            while ((isBasicWordChar(ch) || isAdditionalWordChar(ch)) && i < offset)
+		char ch = lineData[i];
+		if (isBasicWordChar(ch) || isAdditionalWordChar(ch)) //part of identifier
+		{
+			int tokenLen = 0;
+			char* begin = lineData + i;
+			while ((isBasicWordChar(ch) || isAdditionalWordChar(ch)) && i < offset)
 			{
 				++tokenLen;
 				++i;
 				ch = lineData[i];
 			}
 			tokenVector.push_back(Token(begin, tokenLen, true));
-			i--;	//correct overshooting of while loop
+			--i; //correct overshooting of while loop
 		}
-        else
-        {
-			if (ch == ' ' || ch == '\t' || ch == '\n' || ch == '\r') 	//whitespace
-            {
+		else
+		{
+			if (ch == ' ' || ch == '\t' || ch == '\n' || ch == '\r') //whitespace
+			{
 				//do nothing
 			}
-            else
-            {
-				tokenLen = 1;
-				tokenVector.push_back(Token(lineData+i, tokenLen, false));
+			else
+			{
+				tokenVector.push_back(Token(lineData + i, 1, false));
 			}
 		}
 	}
@@ -195,10 +197,10 @@ bool FunctionCallTip::getCursorFunction()
 	int scopeLevel = 0;
 	for (size_t i = 0; i < vsize; ++i)
 	{
-		const Token & curToken = tokenVector.at(i);
+		const Token& curToken = tokenVector.at(i);
 		if (curToken.isIdentifier)
 		{
-			curValue.lastIdentifier = static_cast<int32_t>(i);
+			curValue.lastIdentifier = static_cast<int>(i);
 		}
 		else
 		{
@@ -206,16 +208,18 @@ bool FunctionCallTip::getCursorFunction()
 			{
 				++scopeLevel;
 				newValue = curValue;
-				valueVec.push_back(newValue);	//store the current settings, so when this new function doesn't happen to be the 'real' one, we can restore everything
+				valueVec.push_back(newValue); //store the current settings, so when this new function doesn't happen to be the 'real' one, we can restore everything
 				
 				curValue.scopeLevel = scopeLevel;
-				if (i > 0 && curValue.lastIdentifier == static_cast<int32_t>(i) - 1)
-				{	//identifier must be right before (, else we have some expression like "( x + y() )"
+				if (i > 0 && curValue.lastIdentifier == static_cast<int>(i) - 1)
+				{
+					//identifier must be right before (, else we have some expression like "( x + y() )"
 					curValue.lastFunctionIdentifier = curValue.lastIdentifier;
 					curValue.param = 0;
 				}
 				else
-				{	//some expression
+				{
+					//some expression
 					curValue.lastFunctionIdentifier = -1;
 				}
 			}
@@ -226,9 +230,10 @@ bool FunctionCallTip::getCursorFunction()
 			else if (curToken.token[0] == _stop)
 			{
 				if (scopeLevel)	//scope cannot go below -1
-					scopeLevel--;
+					--scopeLevel;
 				if (valueVec.size() > 0)
-				{	//only pop level if scope was of actual function
+				{
+					//only pop level if scope was of actual function
 					curValue = valueVec.back();
 					valueVec.pop_back();
 				}
@@ -250,7 +255,8 @@ bool FunctionCallTip::getCursorFunction()
 	bool res = false;
 
 	if (curValue.lastFunctionIdentifier == -1)
-	{	//not in direct function. Start popping the stack until we empty it, or a func IS found
+	{
+		//not in direct function. Start popping the stack until we empty it, or a func IS found
 		while (curValue.lastFunctionIdentifier == -1 && valueVec.size() > 0)
 		{
 			curValue = valueVec.back();
@@ -265,20 +271,19 @@ bool FunctionCallTip::getCursorFunction()
 		_currentParam = curValue.param;
 
 		bool same = false;
-		if (_funcName)
+		if (_funcName.get())
 		{
 			if (_ignoreCase)
-				same = testNameNoCase(_funcName, funcToken.token, lstrlen(_funcName)) == 0;
+				same = testNameNoCase(_funcName.get(), funcToken.token, static_cast<int>(std::strlen(_funcName.get()))) == 0;
 			else
-				same = wcsncmp(_funcName, funcToken.token, lstrlen(_funcName)) == 0;
+				same = std::strncmp(_funcName.get(), funcToken.token, std::strlen(_funcName.get())) == 0;
 		}
 
 		if (!same)
-		{	//check if we need to reload data
-			delete [] _funcName;
-
-			_funcName = new wchar_t[funcToken.length+1];
-			wcscpy_s(_funcName, funcToken.length+1, funcToken.token);
+		{
+			//check if we need to reload data
+			_funcName.reset(new char[funcToken.length + 1]);
+			::strcpy_s(_funcName.get(), static_cast<size_t>(funcToken.length) + 1, funcToken.token);
 			res = loadFunction();
 		}
 		else
@@ -294,36 +299,35 @@ Find function in XML structure and parse it
 */
 bool FunctionCallTip::loadFunction()
 {
-	reset();	//set everything back to 0
+	reset(); //set everything back to 0
 	//The functions should be ordered, but linear search because we can't access like array
-	_curFunction = NULL;
+	_curFunction = {};
 	//Iterate through all keywords and find the correct function keyword
-	TiXmlElement *funcNode = _pXmlKeyword;
-	
-	for (; funcNode; funcNode = funcNode->NextSiblingElement(L"KeyWord"))
+	for (NppXml::Element funcNode = _xmlKeyword;
+		funcNode;
+		funcNode = NppXml::nextSiblingElement(funcNode, "KeyWord"))
 	{
-		const wchar_t * name = NULL;
-		name = funcNode->Attribute(L"name");
-		if (!name)		//malformed node
+		const char* name = NppXml::attribute(funcNode, "name");
+		if (!name) //malformed node
 			continue;
 		int compVal = 0;
 		if (_ignoreCase)
-			compVal = testNameNoCase(name, _funcName);	//lstrcmpi doesn't work in this case
+			compVal = testNameNoCase(name, _funcName.get()); //lstrcmpi doesn't work in this case
 		else
-			compVal = lstrcmp(name, _funcName);
-		if (!compVal) 	//found it!
-        {
-			const wchar_t * val = funcNode->Attribute(L"func");
+			compVal = std::strcmp(name, _funcName.get());
+		if (compVal == 0) //found it!
+		{
+			const char* val = NppXml::attribute(funcNode, "func");
 			if (val)
 			{
-				if (!lstrcmp(val, L"yes")) 
-                {
+				if (std::strcmp(val, "yes") == 0)
+				{
 					//what we've been looking for
 					_curFunction = funcNode;
 					break;
 				}
-				else 
-                {
+				else
+				{
 					//name matches, but not a function, abort the entire procedure
 					return false;
 				}
@@ -337,33 +341,32 @@ bool FunctionCallTip::loadFunction()
 
 	stringVec paramVec;
 
-	TiXmlElement *overloadNode = _curFunction->FirstChildElement(L"Overload");
-	TiXmlElement *paramNode = NULL;
-	for (; overloadNode ; overloadNode = overloadNode->NextSiblingElement(L"Overload") )
+	for (NppXml::Element overloadNode = NppXml::firstChildElement(_curFunction, "Overload");
+		overloadNode;
+		overloadNode = NppXml::nextSiblingElement(overloadNode, "Overload"))
 	{
-		const wchar_t * retVal = overloadNode->Attribute(L"retVal");
+		const char* retVal = NppXml::attribute(overloadNode, "retVal");
 		if (!retVal)
-			continue;	//malformed node
+			continue; //malformed node
 		_retVals.push_back(retVal);
 
-		const wchar_t * description = overloadNode->Attribute(L"descr");
+		const char* description = NppXml::attribute(overloadNode, "descr");
 		if (description)
 			_descriptions.push_back(description);
 		else
-			_descriptions.push_back(L"");	//"no description available"
+			_descriptions.push_back(""); //"no description available"
 
-		paramNode = overloadNode->FirstChildElement(L"Param");
-		for (; paramNode ; paramNode = paramNode->NextSiblingElement(L"Param") )
+		for (NppXml::Element paramNode = NppXml::firstChildElement(overloadNode, "Param");
+			paramNode;
+			paramNode = NppXml::nextSiblingElement(paramNode, "Param"))
 		{
-			const wchar_t * param = paramNode->Attribute(L"name");
+			const char* param = NppXml::attribute(paramNode, "name");
 			if (!param)
-				continue;	//malformed node
+				continue; //malformed node
 			paramVec.push_back(param);
 		}
 		_overloads.push_back(paramVec);
 		paramVec.clear();
-
-		++_currentNbOverloads;
 	}
 
 	_currentNbOverloads = _overloads.size();
@@ -377,14 +380,14 @@ bool FunctionCallTip::loadFunction()
 void FunctionCallTip::showCalltip() 
 {
 	if (_currentNbOverloads == 0)
-    {
+	{
 		//ASSERT
 		return;
 	}
 
 	//Check if the current overload still holds. If the current param exceeds amounti n overload, see if another one fits better (enough params)
-	stringVec & params = _overloads.at(_currentOverload);
-	size_t psize = params.size()+1;
+	const stringVec& params = _overloads.at(_currentOverload);
+	size_t psize = params.size() + 1;
 	if (_currentParam >= psize)
 	{
 		size_t osize = _overloads.size();
@@ -399,11 +402,11 @@ void FunctionCallTip::showCalltip()
 		}
 	}
 
-	std::basic_stringstream<wchar_t> callTipText;
+	std::stringstream callTipText;
 
 	if (_currentNbOverloads > 1)
 	{
-		callTipText << L"\001" << _currentOverload + 1 << L" of " << _currentNbOverloads << L"\002";
+		callTipText << "\001" << _currentOverload + 1 << " of " << _currentNbOverloads << "\002";
 	}
 
 	callTipText << _retVals.at(_currentOverload) << ' ' << _funcName << ' ' << _start;
@@ -416,7 +419,7 @@ void FunctionCallTip::showCalltip()
 		if (i == _currentParam) 
 		{
 			highlightstart = static_cast<int>(callTipText.str().length());
-			highlightend = highlightstart + lstrlen(params.at(i));
+			highlightend = highlightstart + static_cast<int>(std::strlen(params.at(i)));
 		}
 		callTipText << params.at(i);
 		if (i < nbParams - 1)
@@ -426,14 +429,14 @@ void FunctionCallTip::showCalltip()
 	callTipText << _stop;
 	if (_descriptions.at(_currentOverload)[0])
 	{
-		callTipText << L"\n" << _descriptions.at(_currentOverload);
+		callTipText << "\n" << _descriptions.at(_currentOverload);
 	}
 
 	if (isVisible())
 		_pEditView->execute(SCI_CALLTIPCANCEL);
 	else
 		_startPos = _curPos;
-	_pEditView->showCallTip(_startPos, callTipText.str().c_str());
+	_pEditView->showCallTip(_startPos, callTipText.str());
 
 	_selfActivated = true;
 	if (highlightstart != highlightend)
@@ -457,7 +460,6 @@ void FunctionCallTip::reset()
 void FunctionCallTip::cleanup()
 {
 	reset();
-	delete [] _funcName;
-	_funcName = 0;
-	_pEditView = NULL;
+	_funcName.reset(nullptr);
+	_pEditView = nullptr;
 }
