@@ -29,17 +29,13 @@ public :
 	ColumnEditorDlg() = default;
 	void init(HINSTANCE hInst, HWND hPere, ScintillaEditView **ppEditView);
 
-	void create(int dialogID, bool isRTL = false, bool msgDestParent = true) override {
-		StaticDialog::create(dialogID, isRTL, msgDestParent);
-	};
-
 	void doDialog(bool isRTL = false) {
 		if (!isCreated())
 			create(IDD_COLUMNEDIT, isRTL);
 		const bool isTextMode = isCheckedOrNot(IDC_COL_TEXT_RADIO);
 		display();
 		::SetFocus(::GetDlgItem(_hSelf, isTextMode?IDC_COL_TEXT_EDIT:IDC_COL_INITNUM_EDIT));
-	};
+	}
 
 	void display(bool toShow = true) const override;
 	void switchTo(bool toText);
