@@ -13,15 +13,14 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
+
 #pragma once
+
+#include <windows.h>
+
 #include "Splitter.h"
-#include "menuCmdID.h"
-
-
-#define SPC_CLASS_NAME L"splitterContainer"
-
-#define ROTATION_LEFT 2000
-#define ROTATION_RIGHT 2001
+#include "Window.h"
 
 
 enum class DIRECTION
@@ -30,24 +29,21 @@ enum class DIRECTION
 	LEFT
 };
 
-
-
-
 class SplitterContainer : public Window
 {
-public :
-	virtual ~SplitterContainer() = default;
+public:
+	~SplitterContainer() override = default;
 
 	void create(Window *pWin0, Window *pWin1, int splitterSize,
-		SplitterMode mode = SplitterMode::DYNAMIC, int ratio = 50, bool _isVertical = true);
+		SplitterMode mode = SplitterMode::DYNAMIC, int ratio = 50, bool isVertical = true);
 
-	void destroy();
+	void destroy() override;
 
-	void reSizeTo(RECT & rc);
+	void reSizeTo(RECT& rc) override;
 
-	virtual void display(bool toShow = true) const;
+	void display(bool toShow = true) const override;
 
-	virtual void redraw(bool forceUpdate = false) const;
+	void redraw(bool forceUpdate = false) const override;
 
 	void setWin0(Window* pWin)
 	{
@@ -64,8 +60,7 @@ public :
 		return ((_dwSplitterStyle & SV_VERTICAL) != 0);
 	}
 
-
-private :
+private:
 	Window* _pWin0 = nullptr; // left or top window
 	Window* _pWin1 = nullptr; // right or bottom window
 
@@ -80,7 +75,7 @@ private :
 	SplitterMode _splitterMode = SplitterMode::DYNAMIC;
 	static bool _isRegistered;
 
-	static LRESULT CALLBACK staticWinProc(HWND hwnd, UINT Message, WPARAM wParam, LPARAM lParam);
-	LRESULT runProc(UINT Message, WPARAM wParam, LPARAM lParam);
+	static LRESULT CALLBACK staticWinProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam);
+	LRESULT runProc(UINT message, WPARAM wParam, LPARAM lParam);
 	void rotateTo(DIRECTION direction);
 };
